@@ -9,7 +9,7 @@ pub fn gen_com_interface(def: &TypeDef, gen: &Gen, include: TypeInclude) -> Toke
 
         let (bases, inspectable) = def.base_interfaces();
 
-        let abi_signatures = bases.iter().rev().chain(core::iter::once(def)).map(|def| def.methods()).flatten().map(|method| {
+        let abi_signatures = bases.iter().rev().chain(core::iter::once(def)).flat_map(|def| def.methods()).map(|method| {
             let signature = method.signature(&[]);
             let abi = gen_win32_abi(&signature, gen);
             if gen.root.is_empty() {
@@ -46,7 +46,7 @@ pub fn gen_com_interface(def: &TypeDef, gen: &Gen, include: TypeInclude) -> Toke
             0
         };
 
-        let methods = method_bases.rev().chain(core::iter::once(def)).map(|def| def.methods()).flatten().enumerate().map(|(vtable_offset, method)| gen_method(base_offset + vtable_offset, &method, &mut method_names, gen));
+        let methods = method_bases.rev().chain(core::iter::once(def)).flat_map(|def| def.methods()).enumerate().map(|(vtable_offset, method)| gen_method(base_offset + vtable_offset, &method, &mut method_names, gen));
 
         let mut conversions = gen_unknown(&name);
 
@@ -151,7 +151,6 @@ fn gen_method(vtable_offset: usize, method: &MethodDef, method_names: &mut BTree
     let name = method.rust_name();
     let overload = method_names.entry(name.to_string()).or_insert(0);
     *overload += 1;
-
     let name: TokenStream = if *overload > 1 { format_token!("{}{}", name, overload) } else { to_ident(&name) };
 
     let features = signature.method_features();
@@ -229,7 +228,7 @@ fn gen_method(vtable_offset: usize, method: &MethodDef, method_names: &mut BTree
                 }
             }
         }
-        SignatureKind::PreserveSig => {
+        SignatureKind::PreserveSig | SignatureKind::ReturnVoid => {
             let params = gen_win32_params(&signature.params, gen);
             let args = signature.params.iter().map(gen_win32_abi_arg);
             let return_sig = gen_win32_return_sig(&signature, gen);
