@@ -5,12 +5,12 @@ pub fn gen_handle() -> TokenStream {
         #[derive(::core::clone::Clone, ::core::marker::Copy, ::core::default::Default, ::core::fmt::Debug, ::core::cmp::PartialEq, ::core::cmp::Eq)]
         #[repr(transparent)]
         pub struct HANDLE(pub isize);
-        unsafe impl ::windows::core::Handle for HANDLE {
-            fn is_invalid(&self) -> bool {
+        impl HANDLE {
+            pub fn is_invalid(&self) -> bool {
                 self.0 == 0 || self.0 == -1
             }
 
-            fn ok(self) -> ::windows::core::Result<Self> {
+            pub fn ok(self) -> ::windows::core::Result<Self> {
                 if self.is_invalid() {
                     Err(::windows::core::Error::from_win32())
                 } else {
