@@ -25,6 +25,7 @@ mod propertykey;
 mod pstr;
 mod pwstr;
 mod r#struct;
+mod sys;
 mod timespan;
 mod to_ident;
 mod tree;
@@ -71,6 +72,7 @@ use r#async::*;
 use r#enum::*;
 use r#struct::*;
 use reader::*;
+use sys::*;
 use timespan::*;
 use vector2::*;
 use vector3::*;
